function [start_indices] = myStrFindi(str, pattern)
% Description:
%   This function will take in a string and some pattern as input, and
%   return the beggining indices of all of the occerences of the patern
%   (ignoring case) in that string.
% Algorithm:
%   1. First the program will apply the lower() function to the inputs,
%   because the function should not account for case.
%   2. The program will next initialize iss_same and start_indices to the
%   empty brackets so that the reference to them before the gain values
%   will not cause an error.
%   3. Next the outer loop will run. From 1 to the length of the string,
%   the for loop will check to see if the position starts the pattern. If
%   it does, the loop will it will add the current position to
%   start_indices. It will then set is_true to [] for the next iteration.
%   4. Inside the loop in 3, another loop will run. The result of the loop
%   will be a vector of logicals, all true if the pattern starts with the
%   str_pos. From 1 to the length of the pattern, the program checks first
%   whether it is indexing out of the string, then whether or not the
%   current position on the pattern matches the current position on the
%   string. It will add this logical value to is_same each time, returning
%   a vector of logicals.
%

% Step 1:
str = lower(str);           % These two lines make the strings both lowercase
pattern = lower(pattern);   % so that the chars will return equal even if they
                            % originally in a different case
% Step 2        
is_same = [];               % These two lines initialize these vectors so as
start_indices = [];         % not to cause errors

% Step 3
for char_pos = 1:length(str)    % Repeats action from the first position on the
                                % string to the last    
    % Step 4
    for patt_pos = 1:length(pattern);
        is_same = [is_same, (char_pos+patt_pos-1)<=length(str) && str(char_pos+patt_pos-1) == pattern(patt_pos)];
        % The line above adds the logical result of whether or not the
        % current position on the string is equal to the current position on the 
        % pattern to is_same. Does short circuit to check that the logical comparison
        % does not index out of bounds.
    end
    if all(is_same) % Only returns true if every value equals the pattern
       start_indices = [start_indices, char_pos]; % Adds the current position to the position vector
    end
    is_same = [];   % Refreshes the is_same for the next iteration of the loop
end

end
